@@ -101,4 +101,10 @@ class UpdateMonitorRequest(RpcRequest):
 		return self.get_body_params().get('DeviceList')
 
 	def set_DeviceList(self,DeviceList):
-		self.add_body_params('DeviceList', DeviceList)
\ No newline at end of file
+		self.add_body_params('DeviceList', DeviceList)
+
+	def get_AlgorithmVendor(self):
+		return self.get_body_params().get('AlgorithmVendor')
+
+	def set_AlgorithmVendor(self,AlgorithmVendor):
+		self.add_body_params('AlgorithmVendor', AlgorithmVendor)
\ No newline at end of file
